@@ -6,7 +6,7 @@
    Backend for idraw files
    Contributed by: Scott Pakin <scott+ps2ed_AT_pakin.org>
 
-   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2021 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ private:
      //  int           objectId;
        TempFile      tempFile;
        ofstream      &buffer;
-       int           imgcount;
+       //int           imgcount;
 
 
 
